Packages

package crypto

Ordering
  1. Alphabetic
Visibility
  1. Public
  2. Protected

Type Members

  1. abstract class BaseHexEncryption[A] extends HexEncryption[A]

    Abstract base class which extends Encryption and provides methods for encrypt/decrypt hex strings.

    Abstract base class which extends Encryption and provides methods for encrypt/decrypt hex strings.

    A

    the cipher algorithm.

  2. trait Encryption[A] extends AnyRef

    Typeclass trait to deal with Encryption for Strings.

    Typeclass trait to deal with Encryption for Strings. The encoding of the Strings is dependent on the concrete implementation of this trait.

    It is general in nature, but has only been tested with JCA AES128CTR.

    A

    the cipher algorithm.

  3. trait HexEncryption[A] extends Encryption[A]

    Typeclass trait to deal with Encryption to/from Hex strings.

    Typeclass trait to deal with Encryption to/from Hex strings.

    A

    the cipher algorithm.

Value Members

  1. object Base64Encryption
  2. object Encryption
  3. object EncryptionUTF8AES128CTR extends BaseHexEncryption[AES128CTR]

    An object which provides hex-encryption based on AES128CTR for UTF-8 Strings.

  4. object HexEncryption

Ungrouped