Packages

trait Encryption[A] extends AnyRef

Typeclass trait to deal with Encryption for Strings. The encoding of the Strings is dependent on the concrete implementation of this trait.

It is general in nature, but has only been tested with JCA AES128CTR.

A

the cipher algorithm.

Linear Supertypes
AnyRef, Any
Ordering
  1. Alphabetic
  2. By Inheritance
Inherited
  1. Encryption
  2. AnyRef
  3. Any
  1. Hide All
  2. Show All
Visibility
  1. Public
  2. Protected

Abstract Value Members

  1. abstract def buildKey(raw: String): IO[SecretKey[A]]

    Build a key from the given String.

    Build a key from the given String.

    raw

    a String of the required length (typically the result of calling genRawKey).

    returns

    an IO of SecretKey[A]

  2. abstract def bytesToCipherText(bytes: Array[Byte]): IO[CipherText[A]]

    THe inverse of concat.

    THe inverse of concat.

    bytes

    the byte array.

    returns

    an IO of CipherText[A].

  3. abstract def concat(cipher: CipherText[A]): IO[Array[Byte]]

    Show the given cipher text as a an array of bytes.

    Show the given cipher text as a an array of bytes.

    cipher

    an instance of CipherText[A].

    returns

    an IO of Array[Byte].

  4. abstract def decrypt(key: SecretKey[A])(cipher: CipherText[A]): IO[String]

    Decrypt the given cipher text.

    Decrypt the given cipher text.

    key

    the key with which to decrypt the cipher text.

    cipher

    an instance of CipherText[A].

    returns

    an IO of String.

  5. abstract def encrypt(key: SecretKey[A])(plaintext: String): IO[CipherText[A]]

    Encrypt a plain text String.

    Encrypt a plain text String.

    key

    the key with which to encrypt the plain text.

    plaintext

    the plain text to encrypt.

    returns

    an IO of CipherText[A].

  6. abstract def genRawKey: IO[String]

    Generate a random String of the required length.

    Generate a random String of the required length.

    returns

    an IO of String.

Concrete Value Members

  1. final def !=(arg0: Any): Boolean
    Definition Classes
    AnyRef → Any
  2. final def ##: Int
    Definition Classes
    AnyRef → Any
  3. final def ==(arg0: Any): Boolean
    Definition Classes
    AnyRef → Any
  4. final def asInstanceOf[T0]: T0
    Definition Classes
    Any
  5. def clone(): AnyRef
    Attributes
    protected[lang]
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.CloneNotSupportedException]) @IntrinsicCandidate() @native()
  6. final def eq(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef
  7. def equals(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef → Any
  8. final def getClass(): Class[_ <: AnyRef]
    Definition Classes
    AnyRef → Any
    Annotations
    @IntrinsicCandidate() @native()
  9. def hashCode(): Int
    Definition Classes
    AnyRef → Any
    Annotations
    @IntrinsicCandidate() @native()
  10. final def isInstanceOf[T0]: Boolean
    Definition Classes
    Any
  11. final def ne(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef
  12. final def notify(): Unit
    Definition Classes
    AnyRef
    Annotations
    @IntrinsicCandidate() @native()
  13. final def notifyAll(): Unit
    Definition Classes
    AnyRef
    Annotations
    @IntrinsicCandidate() @native()
  14. final def synchronized[T0](arg0: => T0): T0
    Definition Classes
    AnyRef
  15. def toString(): String
    Definition Classes
    AnyRef → Any
  16. final def wait(arg0: Long, arg1: Int): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException])
  17. final def wait(arg0: Long): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException]) @native()
  18. final def wait(): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException])

Deprecated Value Members

  1. def finalize(): Unit
    Attributes
    protected[lang]
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.Throwable]) @Deprecated
    Deprecated

    (Since version 9)

Inherited from AnyRef

Inherited from Any

Ungrouped