Packages

o

com.phasmidsoftware.tableparser.cats.crypto

EncryptionUTF8AES128CTR

object EncryptionUTF8AES128CTR extends BaseHexEncryption[AES128CTR]

An object which provides hex-encryption based on AES128CTR for UTF-8 Strings.

Linear Supertypes
BaseHexEncryption[AES128CTR], HexEncryption[AES128CTR], Encryption[AES128CTR], AnyRef, Any
Ordering
  1. Alphabetic
  2. By Inheritance
Inherited
  1. EncryptionUTF8AES128CTR
  2. BaseHexEncryption
  3. HexEncryption
  4. Encryption
  5. AnyRef
  6. Any
  1. Hide All
  2. Show All
Visibility
  1. Public
  2. Protected

Value Members

  1. final def !=(arg0: Any): Boolean
    Definition Classes
    AnyRef → Any
  2. final def ##: Int
    Definition Classes
    AnyRef → Any
  3. final def ==(arg0: Any): Boolean
    Definition Classes
    AnyRef → Any
  4. final def asInstanceOf[T0]: T0
    Definition Classes
    Any
  5. def buildKey(rawKey: String): IO[SecretKey[AES128CTR]]

    Build a key from the given String.

    Build a key from the given String.

    returns

    an IO of SecretKey[A]

    Definition Classes
    EncryptionUTF8AES128CTREncryption
  6. def bytesToCipherText(bytes: Array[Byte]): IO[CipherText[AES128CTR]]

    THe inverse of concat.

    THe inverse of concat.

    bytes

    the byte array.

    returns

    an IO of CipherText[A].

    Definition Classes
    EncryptionUTF8AES128CTREncryption
  7. implicit val cachedInstance: JCAPrimitiveCipher[IO, AES128CTR, CTR, NoPadding]
  8. def checkHex(hex: String, key: SecretKey[AES128CTR], plaintext: String): IO[Boolean]

    Method to check that the given Hex String really does decrypt to the given plaintext.

    Method to check that the given Hex String really does decrypt to the given plaintext.

    hex

    a String of hexadecimals.

    key

    the secret key.

    plaintext

    the original plain text.

    returns

    true if the Hex string is correct.

    Definition Classes
    BaseHexEncryptionHexEncryption
  9. def clone(): AnyRef
    Attributes
    protected[lang]
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.CloneNotSupportedException]) @IntrinsicCandidate() @native()
  10. def concat(cipher: CipherText[AES128CTR]): IO[Array[Byte]]

    Show the given cipher text as a an array of bytes.

    Show the given cipher text as a an array of bytes.

    cipher

    an instance of CipherText[A].

    returns

    an IO of Array[Byte].

    Definition Classes
    EncryptionUTF8AES128CTREncryption
  11. implicit val ctrStrategy: IvGen[IO, AES128CTR]
  12. def decrypt(key: SecretKey[AES128CTR])(cipher: CipherText[AES128CTR]): IO[String]

    Decrypt the given cipher text.

    Decrypt the given cipher text.

    key

    the key with which to decrypt the cipher text.

    cipher

    an instance of CipherText[A].

    returns

    an IO of String.

    Definition Classes
    EncryptionUTF8AES128CTREncryption
  13. def decryptHex(rawKey: String, hex: String): IO[String]

    Given a raw key and a Hex string, do the decryption.

    Given a raw key and a Hex string, do the decryption.

    rawKey

    a raw key, i.e. a sequence of 16 characters.

    hex

    a string of Hexadecimal digits representing a cipher.

    returns

    the decrypted String, wrapped in IO.

    Definition Classes
    BaseHexEncryptionHexEncryption
  14. def encrypt(key: SecretKey[AES128CTR])(plaintext: String): IO[CipherText[AES128CTR]]

    Encrypt a plain text String.

    Encrypt a plain text String.

    key

    the key with which to encrypt the plain text.

    plaintext

    the plain text to encrypt.

    returns

    an IO of CipherText[A].

    Definition Classes
    EncryptionUTF8AES128CTREncryption
  15. def encryptWithRandomKey(plaintext: CharSequence): IO[(String, String, Boolean)]

    Encrypt a plain text String but using a randomly generated key.

    Encrypt a plain text String but using a randomly generated key. The key, together with the encrypted text as hex and a check boolean, is returned.

    plaintext

    the plain text to be encrypted.

    returns

    a tuple of the raw key, the encrypted cipher (as hex), and a boolean, all wrapped in IO.

    Definition Classes
    BaseHexEncryptionHexEncryption
  16. final def eq(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef
  17. def equals(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef → Any
  18. def genRawKey: IO[String]

    Method to get a raw key, wrapped in IO.

    Method to get a raw key, wrapped in IO.

    NOTE: this way of doing things is slow.

    returns

    an IO of String.

    Definition Classes
    BaseHexEncryptionEncryption
  19. final def getClass(): Class[_ <: AnyRef]
    Definition Classes
    AnyRef → Any
    Annotations
    @IntrinsicCandidate() @native()
  20. def hashCode(): Int
    Definition Classes
    AnyRef → Any
    Annotations
    @IntrinsicCandidate() @native()
  21. final def isInstanceOf[T0]: Boolean
    Definition Classes
    Any
  22. final def ne(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef
  23. final def notify(): Unit
    Definition Classes
    AnyRef
    Annotations
    @IntrinsicCandidate() @native()
  24. final def notifyAll(): Unit
    Definition Classes
    AnyRef
    Annotations
    @IntrinsicCandidate() @native()
  25. final def synchronized[T0](arg0: => T0): T0
    Definition Classes
    AnyRef
  26. def toString(): String
    Definition Classes
    AnyRef → Any
  27. final def wait(arg0: Long, arg1: Int): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException])
  28. final def wait(arg0: Long): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException]) @native()
  29. final def wait(): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException])

Deprecated Value Members

  1. def finalize(): Unit
    Attributes
    protected[lang]
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.Throwable]) @Deprecated
    Deprecated

    (Since version 9)

Inherited from BaseHexEncryption[AES128CTR]

Inherited from HexEncryption[AES128CTR]

Inherited from Encryption[AES128CTR]

Inherited from AnyRef

Inherited from Any

Ungrouped