Packages

package parse

Type Members

  1. case class EncryptedHeadedStringTableParser[X, A](encryptedRowPredicate: (String) => Boolean, keyFunction: (String) => String, maybeHeader: Option[Header] = None, forgiving: Boolean = false, headerRowsToRead: Int = 1)(implicit evidence$1: CellParser[X], evidence$2: ClassTag[X], evidence$3: HexEncryption[A]) extends HeadedStringTableParser[X] with Product with Serializable

    Case class to define a StringTableParser that assumes a header to be found in the input file.

    Case class to define a StringTableParser that assumes a header to be found in the input file. This class attempts to provide as much built-in functionality as possible.

    This class assumes that the names of the columns are in the first line. This class implements builder with a HeadedTable object. This class uses StandardRowParser of its rowParser.

    X

    the underlying row type for which there must be evidence of a CellParser and ClassTag.

    A

    the cipher algorithm (for which there must be evidence of HexEncryption[A]).

    encryptedRowPredicate

    a function which takes a String and returns a Boolean.

    keyFunction

    a function which takes a String and returns a String (input might be ignored).

    maybeHeader

    None => requires that the data source has a header row. Some(h) => specifies that the header is to be taken from h. Defaults to None. NOTE: that the simplest is to specify the header directly from the type X.

    forgiving

    if true, exceptions when parsing individual rows will be logged then ignored. if false, any exception will terminate the parsing. Defaults to false.

    headerRowsToRead

    the number of header rows expected in the input file defaults to 1.

Ungrouped