Packages

package render

Type Members

  1. case class CsvTableEncryptedFileRenderer[T, A](file: File)(implicit evidence$1: CsvRenderer[T], evidence$2: CsvGenerator[T], evidence$3: HasKey[T], evidence$4: HexEncryption[A], csvAttributes: CsvAttributes) extends CsvTableRenderer[T, FileWriter] with Product with Serializable

    Case class to help render a Table to a File in CSV format.

    Case class to help render a Table to a File in CSV format.

    TODO remove duplicate code

    TESTME

    T

    the type of object to be rendered, must provide evidence of CsvRenderer[T] amd CsvGenerator[T].

    A

    the cipher algorithm (for which there must be evidence of HexEncryption[A]).

    file

    the file to which the table will be written.

    csvAttributes

    implicit instance of CsvAttributes.

Ungrouped