Packages

c

com.phasmidsoftware.tableparser.cats.render

CsvTableEncryptedFileRenderer

case class CsvTableEncryptedFileRenderer[T, A](file: File)(implicit evidence$1: CsvRenderer[T], evidence$2: CsvGenerator[T], evidence$3: HasKey[T], evidence$4: HexEncryption[A], csvAttributes: CsvAttributes) extends CsvTableRenderer[T, FileWriter] with Product with Serializable

Case class to help render a Table to a File in CSV format.

TODO remove duplicate code

TESTME

T

the type of object to be rendered, must provide evidence of CsvRenderer[T] amd CsvGenerator[T].

A

the cipher algorithm (for which there must be evidence of HexEncryption[A]).

file

the file to which the table will be written.

csvAttributes

implicit instance of CsvAttributes.

Linear Supertypes
Serializable, Product, Equals, CsvTableRenderer[T, FileWriter], Renderer[Table[T], Try[FileWriter]], AnyRef, Any
Ordering
  1. Alphabetic
  2. By Inheritance
Inherited
  1. CsvTableEncryptedFileRenderer
  2. Serializable
  3. Product
  4. Equals
  5. CsvTableRenderer
  6. Renderer
  7. AnyRef
  8. Any
  1. Hide All
  2. Show All
Visibility
  1. Public
  2. Protected

Instance Constructors

  1. new CsvTableEncryptedFileRenderer(file: File)(implicit arg0: CsvRenderer[T], arg1: CsvGenerator[T], arg2: HasKey[T], arg3: HexEncryption[A], csvAttributes: CsvAttributes)

    file

    the file to which the table will be written.

    csvAttributes

    implicit instance of CsvAttributes.

Value Members

  1. final def !=(arg0: Any): Boolean
    Definition Classes
    AnyRef → Any
  2. final def ##: Int
    Definition Classes
    AnyRef → Any
  3. final def ==(arg0: Any): Boolean
    Definition Classes
    AnyRef → Any
  4. final def asInstanceOf[T0]: T0
    Definition Classes
    Any
  5. def clone(): AnyRef
    Attributes
    protected[lang]
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.CloneNotSupportedException]) @IntrinsicCandidate() @native()
  6. final def eq(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef
  7. val file: File
  8. def generateText(ow: Writable[FileWriter], tc: CsvRenderer[T], o: FileWriter, t: T): FileWriter
    Attributes
    protected
    Definition Classes
    CsvTableEncryptedFileRenderer → CsvTableRenderer
  9. final def getClass(): Class[_ <: AnyRef]
    Definition Classes
    AnyRef → Any
    Annotations
    @IntrinsicCandidate() @native()
  10. final def isInstanceOf[T0]: Boolean
    Definition Classes
    Any
  11. final def ne(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef
  12. final def notify(): Unit
    Definition Classes
    AnyRef
    Annotations
    @IntrinsicCandidate() @native()
  13. final def notifyAll(): Unit
    Definition Classes
    AnyRef
    Annotations
    @IntrinsicCandidate() @native()
  14. def productElementNames: Iterator[String]
    Definition Classes
    Product
  15. def render(t: Table[T], attrs: Map[String, String]): Try[FileWriter]
    Definition Classes
    CsvTableRenderer → Renderer
  16. def render(t: Table[T]): Try[FileWriter]
    Definition Classes
    Renderer
  17. final def synchronized[T0](arg0: => T0): T0
    Definition Classes
    AnyRef
  18. final def wait(arg0: Long, arg1: Int): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException])
  19. final def wait(arg0: Long): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException]) @native()
  20. final def wait(): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException])

Deprecated Value Members

  1. def finalize(): Unit
    Attributes
    protected[lang]
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.Throwable]) @Deprecated
    Deprecated

    (Since version 9)

Inherited from Serializable

Inherited from Product

Inherited from Equals

Inherited from CsvTableRenderer[T, FileWriter]

Inherited from Renderer[Table[T], Try[FileWriter]]

Inherited from AnyRef

Inherited from Any

Ungrouped