Packages

object IOUsing

Cats effect IO equivalent of TryUsing

Linear Supertypes
AnyRef, Any
Ordering
  1. Alphabetic
  2. By Inheritance
Inherited
  1. IOUsing
  2. AnyRef
  3. Any
  1. Hide All
  2. Show All
Visibility
  1. Public
  2. Protected

Value Members

  1. final def !=(arg0: Any): Boolean
    Definition Classes
    AnyRef → Any
  2. final def ##: Int
    Definition Classes
    AnyRef → Any
  3. final def ==(arg0: Any): Boolean
    Definition Classes
    AnyRef → Any
  4. def apply[R, A](ry: Try[R])(f: (R) => IO[A])(implicit arg0: Releasable[R]): IO[A]

    This alternative apply method signature is to allow proper handling of Releasable resources which are themselves wrapped in Try, using IO.

    This alternative apply method signature is to allow proper handling of Releasable resources which are themselves wrapped in Try, using IO.

    CONSIDER making the ry parameter non-strict (but then we would have to rename this method something else).

    R

    the resource type.

    A

    the underlying type of the result.

    ry

    a Try of a resource which is to be used by f and will be managed by Resource.

    f

    a function of R => IO[A].

    returns

    a IO[A]

  5. def apply[R, A](ri: IO[R])(f: (R) => IO[A])(implicit arg0: Releasable[R]): IO[A]

    This alternative apply method signature is to allow proper handling of Releasable resources which are themselves wrapped in IO, using IO.

    This alternative apply method signature is to allow proper handling of Releasable resources which are themselves wrapped in IO, using IO. This method is to Using.apply as flatMap is to Map.

    CONSIDER making the ri parameter non-strict (but then we would have to rename this method something else).

    R

    the resource type.

    A

    the underlying type of the result.

    ri

    an IO of a resource which is to be used by f and will be managed by Resource.

    f

    a function of R => IO[A].

    returns

    a IO[A]

  6. def apply[R, A](resource: => R)(f: (R) => IO[A])(implicit arg0: Releasable[R]): IO[A]

    This apply method is to allow proper handling of Releasable resources, using IO.

    This apply method is to allow proper handling of Releasable resources, using IO.

    R

    the resource type.

    A

    the underlying type of the result.

    resource

    a resource which is used by f and will be managed by Resource.

    f

    a function of R => IO[A].

    returns

    a IO[A], the result of invoking apply(IO(resource))(f).

  7. final def asInstanceOf[T0]: T0
    Definition Classes
    Any
  8. def clone(): AnyRef
    Attributes
    protected[lang]
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.CloneNotSupportedException]) @IntrinsicCandidate() @native()
  9. final def eq(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef
  10. def equals(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef → Any
  11. final def getClass(): Class[_ <: AnyRef]
    Definition Classes
    AnyRef → Any
    Annotations
    @IntrinsicCandidate() @native()
  12. def hashCode(): Int
    Definition Classes
    AnyRef → Any
    Annotations
    @IntrinsicCandidate() @native()
  13. final def isInstanceOf[T0]: Boolean
    Definition Classes
    Any
  14. final def ne(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef
  15. final def notify(): Unit
    Definition Classes
    AnyRef
    Annotations
    @IntrinsicCandidate() @native()
  16. final def notifyAll(): Unit
    Definition Classes
    AnyRef
    Annotations
    @IntrinsicCandidate() @native()
  17. final def synchronized[T0](arg0: => T0): T0
    Definition Classes
    AnyRef
  18. def toString(): String
    Definition Classes
    AnyRef → Any
  19. final def wait(arg0: Long, arg1: Int): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException])
  20. final def wait(arg0: Long): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException]) @native()
  21. final def wait(): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException])

Deprecated Value Members

  1. def finalize(): Unit
    Attributes
    protected[lang]
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.Throwable]) @Deprecated
    Deprecated

    (Since version 9)

Inherited from AnyRef

Inherited from Any

Ungrouped