Packages

trait WritableCrypt[O] extends Writable[O]

Trait to enable rendering of a table to a sequential (non-hierarchical) output format. A typeclass.

O

the underlying type, for example, a StringBuilder.

Linear Supertypes
Writable[O], AnyRef, Any
Ordering
  1. Alphabetic
  2. By Inheritance
Inherited
  1. WritableCrypt
  2. Writable
  3. AnyRef
  4. Any
  1. Hide All
  2. Show All
Visibility
  1. Public
  2. Protected

Abstract Value Members

  1. abstract def unit: O
    Definition Classes
    Writable
  2. abstract def writeRaw(o: O)(x: CharSequence): O
    Definition Classes
    Writable

Concrete Value Members

  1. final def !=(arg0: Any): Boolean
    Definition Classes
    AnyRef → Any
  2. final def ##: Int
    Definition Classes
    AnyRef → Any
  3. final def ==(arg0: Any): Boolean
    Definition Classes
    AnyRef → Any
  4. final def asInstanceOf[T0]: T0
    Definition Classes
    Any
  5. def clone(): AnyRef
    Attributes
    protected[lang]
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.CloneNotSupportedException]) @IntrinsicCandidate() @native()
  6. def close(o: O): Unit
    Definition Classes
    Writable
  7. def delimiter: CharSequence
    Definition Classes
    Writable
  8. final def eq(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef
  9. def equals(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef → Any
  10. final def getClass(): Class[_ <: AnyRef]
    Definition Classes
    AnyRef → Any
    Annotations
    @IntrinsicCandidate() @native()
  11. def hashCode(): Int
    Definition Classes
    AnyRef → Any
    Annotations
    @IntrinsicCandidate() @native()
  12. final def isInstanceOf[T0]: Boolean
    Definition Classes
    Any
  13. final def ne(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef
  14. def newline: CharSequence
    Definition Classes
    Writable
  15. final def notify(): Unit
    Definition Classes
    AnyRef
    Annotations
    @IntrinsicCandidate() @native()
  16. final def notifyAll(): Unit
    Definition Classes
    AnyRef
    Annotations
    @IntrinsicCandidate() @native()
  17. def quote: CharSequence
    Definition Classes
    Writable
  18. final def synchronized[T0](arg0: => T0): T0
    Definition Classes
    AnyRef
  19. def toString(): String
    Definition Classes
    AnyRef → Any
  20. final def wait(arg0: Long, arg1: Int): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException])
  21. final def wait(arg0: Long): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException]) @native()
  22. final def wait(): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException])
  23. def writeLineEncrypted[A](o: O)(key: String, plaintext: CharSequence)(implicit arg0: HexEncryption[A]): O

    Method to write a character sequence to the given instance o followed by a newline.

    Method to write a character sequence to the given instance o followed by a newline.

    A

    the cipher algorithm (for which there must be evidence of Encryption[A]).

    o

    the instance of O whither the parameter x should be written.

    key

    the lookup key for this row (not an encryption key).

    plaintext

    the plain text character sequence to be written in encrypted form.

    returns

    an instance of O which represents the updated output structure.

  24. def writeQuoted(o: O)(x: CharSequence): O
    Definition Classes
    Writable
  25. def writeRawLine(o: O)(x: CharSequence): O
    Definition Classes
    Writable
  26. def writeRow[Row <: Product](o: O)(x: Row): O
    Definition Classes
    Writable
  27. def writeRowElements(o: O)(xs: Seq[Any]): O
    Definition Classes
    Writable
  28. def writeValue(o: O)(x: Any): O
    Definition Classes
    Writable

Deprecated Value Members

  1. def finalize(): Unit
    Attributes
    protected[lang]
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.Throwable]) @Deprecated
    Deprecated

    (Since version 9)

Inherited from Writable[O]

Inherited from AnyRef

Inherited from Any

Ungrouped