object HexEncryption
Linear Supertypes
Ordering
- Alphabetic
- By Inheritance
Inherited
- HexEncryption
- AnyRef
- Any
- Hide All
- Show All
Visibility
- Public
- Protected
Value Members
- final def !=(arg0: Any): Boolean
- Definition Classes
- AnyRef → Any
- final def ##: Int
- Definition Classes
- AnyRef → Any
- final def ==(arg0: Any): Boolean
- Definition Classes
- AnyRef → Any
- final def asInstanceOf[T0]: T0
- Definition Classes
- Any
- def bytesToHexString(bytes: Array[Byte]): IO[String]
Show the given bytes as hexadecimal text.
Show the given bytes as hexadecimal text.
- bytes
an Array[Byte].
- returns
an IO of String.
- def clone(): AnyRef
- Attributes
- protected[lang]
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.CloneNotSupportedException]) @IntrinsicCandidate() @native()
- def decryptRow[A](keyFunction: (String) => String)(row: Seq[String])(implicit arg0: HexEncryption[A]): IO[String]
Method to decrypt a row consisting of an identifier and a Hex string.
Method to decrypt a row consisting of an identifier and a Hex string.
- A
the cipher algorithm (for which there must be evidence of HexEncryption[A]).
- keyFunction
a function to yield the raw cipher key from the value of the ID column (said value might well be ignored).
- row
a two-element sequence of Strings: the id and the hex string. * @tparam A the cipher algorithm.
- returns
a IO[String].
- final def eq(arg0: AnyRef): Boolean
- Definition Classes
- AnyRef
- def equals(arg0: AnyRef): Boolean
- Definition Classes
- AnyRef → Any
- final def getClass(): Class[_ <: AnyRef]
- Definition Classes
- AnyRef → Any
- Annotations
- @IntrinsicCandidate() @native()
- def hashCode(): Int
- Definition Classes
- AnyRef → Any
- Annotations
- @IntrinsicCandidate() @native()
- def hexStringToBytes(hex: String): IO[Array[Byte]]
Decode the given String in hexadecimal as an array of Byte.
Decode the given String in hexadecimal as an array of Byte.
- hex
the hex String.
- returns
Array[Byte].
- final def isInstanceOf[T0]: Boolean
- Definition Classes
- Any
- final def ne(arg0: AnyRef): Boolean
- Definition Classes
- AnyRef
- final def notify(): Unit
- Definition Classes
- AnyRef
- Annotations
- @IntrinsicCandidate() @native()
- final def notifyAll(): Unit
- Definition Classes
- AnyRef
- Annotations
- @IntrinsicCandidate() @native()
- final def synchronized[T0](arg0: => T0): T0
- Definition Classes
- AnyRef
- def toString(): String
- Definition Classes
- AnyRef → Any
- final def wait(arg0: Long, arg1: Int): Unit
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.InterruptedException])
- final def wait(arg0: Long): Unit
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.InterruptedException]) @native()
- final def wait(): Unit
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.InterruptedException])
Deprecated Value Members
- def finalize(): Unit
- Attributes
- protected[lang]
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.Throwable]) @Deprecated
- Deprecated
(Since version 9)