case class CsvTableEncryptedFileRenderer[T, A](file: File)(implicit evidence$1: CsvRenderer[T], evidence$2: CsvGenerator[T], evidence$3: HasKey[T], evidence$4: HexEncryption[A], csvAttributes: CsvAttributes) extends CsvTableRenderer[T, FileWriter] with Product with Serializable
Case class to help render a Table to a File in CSV format.
TODO remove duplicate code
TESTME
- T
the type of object to be rendered, must provide evidence of CsvRenderer[T] amd CsvGenerator[T].
- A
the cipher algorithm (for which there must be evidence of HexEncryption[A]).
- file
the file to which the table will be written.
- csvAttributes
implicit instance of CsvAttributes.
Linear Supertypes
Ordering
- Alphabetic
- By Inheritance
Inherited
- CsvTableEncryptedFileRenderer
- Serializable
- Product
- Equals
- CsvTableRenderer
- Renderer
- AnyRef
- Any
- Hide All
- Show All
Visibility
- Public
- Protected
Instance Constructors
- new CsvTableEncryptedFileRenderer(file: File)(implicit arg0: CsvRenderer[T], arg1: CsvGenerator[T], arg2: HasKey[T], arg3: HexEncryption[A], csvAttributes: CsvAttributes)
- file
the file to which the table will be written.
- csvAttributes
implicit instance of CsvAttributes.
Value Members
- final def !=(arg0: Any): Boolean
- Definition Classes
- AnyRef → Any
- final def ##: Int
- Definition Classes
- AnyRef → Any
- final def ==(arg0: Any): Boolean
- Definition Classes
- AnyRef → Any
- final def asInstanceOf[T0]: T0
- Definition Classes
- Any
- def clone(): AnyRef
- Attributes
- protected[lang]
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.CloneNotSupportedException]) @IntrinsicCandidate() @native()
- final def eq(arg0: AnyRef): Boolean
- Definition Classes
- AnyRef
- val file: File
- def generateText(ow: Writable[FileWriter], tc: CsvRenderer[T], o: FileWriter, t: T): FileWriter
- Attributes
- protected
- Definition Classes
- CsvTableEncryptedFileRenderer → CsvTableRenderer
- final def getClass(): Class[_ <: AnyRef]
- Definition Classes
- AnyRef → Any
- Annotations
- @IntrinsicCandidate() @native()
- final def isInstanceOf[T0]: Boolean
- Definition Classes
- Any
- final def ne(arg0: AnyRef): Boolean
- Definition Classes
- AnyRef
- final def notify(): Unit
- Definition Classes
- AnyRef
- Annotations
- @IntrinsicCandidate() @native()
- final def notifyAll(): Unit
- Definition Classes
- AnyRef
- Annotations
- @IntrinsicCandidate() @native()
- def productElementNames: Iterator[String]
- Definition Classes
- Product
- def render(t: Table[T], attrs: Map[String, String]): Try[FileWriter]
- Definition Classes
- CsvTableRenderer → Renderer
- def render(t: Table[T]): Try[FileWriter]
- Definition Classes
- Renderer
- final def synchronized[T0](arg0: => T0): T0
- Definition Classes
- AnyRef
- final def wait(arg0: Long, arg1: Int): Unit
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.InterruptedException])
- final def wait(arg0: Long): Unit
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.InterruptedException]) @native()
- final def wait(): Unit
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.InterruptedException])
Deprecated Value Members
- def finalize(): Unit
- Attributes
- protected[lang]
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.Throwable]) @Deprecated
- Deprecated
(Since version 9)