object IOUsing
Cats effect IO equivalent of TryUsing
- Alphabetic
- By Inheritance
- IOUsing
- AnyRef
- Any
- Hide All
- Show All
- Public
- Protected
Value Members
- final def !=(arg0: Any): Boolean
- Definition Classes
- AnyRef → Any
- final def ##: Int
- Definition Classes
- AnyRef → Any
- final def ==(arg0: Any): Boolean
- Definition Classes
- AnyRef → Any
- def apply[R, A](ry: Try[R])(f: (R) => IO[A])(implicit arg0: Releasable[R]): IO[A]
This alternative apply method signature is to allow proper handling of Releasable resources which are themselves wrapped in Try, using IO.
This alternative apply method signature is to allow proper handling of Releasable resources which are themselves wrapped in Try, using IO.
CONSIDER making the ry parameter non-strict (but then we would have to rename this method something else).
- R
the resource type.
- A
the underlying type of the result.
- ry
a Try of a resource which is to be used by f and will be managed by Resource.
- f
a function of R => IO[A].
- returns
a IO[A]
- def apply[R, A](ri: IO[R])(f: (R) => IO[A])(implicit arg0: Releasable[R]): IO[A]
This alternative apply method signature is to allow proper handling of Releasable resources which are themselves wrapped in IO, using IO.
This alternative apply method signature is to allow proper handling of Releasable resources which are themselves wrapped in IO, using IO. This method is to Using.apply as flatMap is to Map.
CONSIDER making the ri parameter non-strict (but then we would have to rename this method something else).
- R
the resource type.
- A
the underlying type of the result.
- ri
an IO of a resource which is to be used by f and will be managed by Resource.
- f
a function of R => IO[A].
- returns
a IO[A]
- def apply[R, A](resource: => R)(f: (R) => IO[A])(implicit arg0: Releasable[R]): IO[A]
This apply method is to allow proper handling of Releasable resources, using IO.
This apply method is to allow proper handling of Releasable resources, using IO.
- R
the resource type.
- A
the underlying type of the result.
- resource
a resource which is used by f and will be managed by Resource.
- f
a function of R => IO[A].
- returns
a IO[A], the result of invoking apply(IO(resource))(f).
- final def asInstanceOf[T0]: T0
- Definition Classes
- Any
- def clone(): AnyRef
- Attributes
- protected[lang]
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.CloneNotSupportedException]) @IntrinsicCandidate() @native()
- final def eq(arg0: AnyRef): Boolean
- Definition Classes
- AnyRef
- def equals(arg0: AnyRef): Boolean
- Definition Classes
- AnyRef → Any
- final def getClass(): Class[_ <: AnyRef]
- Definition Classes
- AnyRef → Any
- Annotations
- @IntrinsicCandidate() @native()
- def hashCode(): Int
- Definition Classes
- AnyRef → Any
- Annotations
- @IntrinsicCandidate() @native()
- final def isInstanceOf[T0]: Boolean
- Definition Classes
- Any
- final def ne(arg0: AnyRef): Boolean
- Definition Classes
- AnyRef
- final def notify(): Unit
- Definition Classes
- AnyRef
- Annotations
- @IntrinsicCandidate() @native()
- final def notifyAll(): Unit
- Definition Classes
- AnyRef
- Annotations
- @IntrinsicCandidate() @native()
- final def synchronized[T0](arg0: => T0): T0
- Definition Classes
- AnyRef
- def toString(): String
- Definition Classes
- AnyRef → Any
- final def wait(arg0: Long, arg1: Int): Unit
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.InterruptedException])
- final def wait(arg0: Long): Unit
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.InterruptedException]) @native()
- final def wait(): Unit
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.InterruptedException])
Deprecated Value Members
- def finalize(): Unit
- Attributes
- protected[lang]
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.Throwable]) @Deprecated
- Deprecated
(Since version 9)