trait WritableCrypt[O] extends Writable[O]
Trait to enable rendering of a table to a sequential (non-hierarchical) output format. A typeclass.
- O
the underlying type, for example, a StringBuilder.
Linear Supertypes
Ordering
- Alphabetic
- By Inheritance
Inherited
- WritableCrypt
- Writable
- AnyRef
- Any
- Hide All
- Show All
Visibility
- Public
- Protected
Abstract Value Members
- abstract def unit: O
- Definition Classes
- Writable
- abstract def writeRaw(o: O)(x: CharSequence): O
- Definition Classes
- Writable
Concrete Value Members
- final def !=(arg0: Any): Boolean
- Definition Classes
- AnyRef → Any
- final def ##: Int
- Definition Classes
- AnyRef → Any
- final def ==(arg0: Any): Boolean
- Definition Classes
- AnyRef → Any
- final def asInstanceOf[T0]: T0
- Definition Classes
- Any
- def clone(): AnyRef
- Attributes
- protected[lang]
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.CloneNotSupportedException]) @IntrinsicCandidate() @native()
- def close(o: O): Unit
- Definition Classes
- Writable
- def delimiter: CharSequence
- Definition Classes
- Writable
- final def eq(arg0: AnyRef): Boolean
- Definition Classes
- AnyRef
- def equals(arg0: AnyRef): Boolean
- Definition Classes
- AnyRef → Any
- final def getClass(): Class[_ <: AnyRef]
- Definition Classes
- AnyRef → Any
- Annotations
- @IntrinsicCandidate() @native()
- def hashCode(): Int
- Definition Classes
- AnyRef → Any
- Annotations
- @IntrinsicCandidate() @native()
- final def isInstanceOf[T0]: Boolean
- Definition Classes
- Any
- final def ne(arg0: AnyRef): Boolean
- Definition Classes
- AnyRef
- def newline: CharSequence
- Definition Classes
- Writable
- final def notify(): Unit
- Definition Classes
- AnyRef
- Annotations
- @IntrinsicCandidate() @native()
- final def notifyAll(): Unit
- Definition Classes
- AnyRef
- Annotations
- @IntrinsicCandidate() @native()
- def quote: CharSequence
- Definition Classes
- Writable
- final def synchronized[T0](arg0: => T0): T0
- Definition Classes
- AnyRef
- def toString(): String
- Definition Classes
- AnyRef → Any
- final def wait(arg0: Long, arg1: Int): Unit
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.InterruptedException])
- final def wait(arg0: Long): Unit
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.InterruptedException]) @native()
- final def wait(): Unit
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.InterruptedException])
- def writeLineEncrypted[A](o: O)(key: String, plaintext: CharSequence)(implicit arg0: HexEncryption[A]): O
Method to write a character sequence to the given instance o followed by a newline.
Method to write a character sequence to the given instance o followed by a newline.
- A
the cipher algorithm (for which there must be evidence of Encryption[A]).
- o
the instance of O whither the parameter x should be written.
- key
the lookup key for this row (not an encryption key).
- plaintext
the plain text character sequence to be written in encrypted form.
- returns
an instance of O which represents the updated output structure.
- def writeQuoted(o: O)(x: CharSequence): O
- Definition Classes
- Writable
- def writeRawLine(o: O)(x: CharSequence): O
- Definition Classes
- Writable
- def writeRow[Row <: Product](o: O)(x: Row): O
- Definition Classes
- Writable
- def writeRowElements(o: O)(xs: Seq[Any]): O
- Definition Classes
- Writable
- def writeValue(o: O)(x: Any): O
- Definition Classes
- Writable
Deprecated Value Members
- def finalize(): Unit
- Attributes
- protected[lang]
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.Throwable]) @Deprecated
- Deprecated
(Since version 9)